@@ -5,7 +5,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # $VERSION = eval $VERSION;    ## no critic (eval)
 
@@ -23,9 +23,7 @@ sub new {
     $args{algorithm} = 'SHA-512';
 
     # We're doing our own random salt generation.
-    if ( exists $args{salt_random} ) {
-        delete $args{salt_random};
-    }
+    delete $args{salt_random};
 
     # If there is no hash supplied, and a passphrase is supplied, this must be
     # a passphrase hash/salt generation object.
@@ -37,14 +35,10 @@ sub new {
         # Generate a 512 bit random salt using a secure random generator.
         # 64 bytes is 512 bits, or 128 hex characters.
         my $salt = random_bytes_hex(NUM_BYTES);
-        
-        for (qw( salt salt_hash )) {
 
-            # We're generating our own salt.  Don't accept others.
-            if ( exists $args{$_} ) {
-                delete $args{$_};
-            }
-        }
+        # We're generating our own salt.  Don't accept others.
+        delete $args{$_} for qw( salt salt_hash );
+
         $args{salt_hex} = $salt;
     }
 
@@ -73,12 +67,12 @@ __END__
 
 =head1 NAME
 
-Authen::Passphrase::SaltedSHA512 - Safe, Sane, and Simple passphrase generation
-and authentication.
+Authen::Passphrase::SaltedSHA512 - Safe, Sane, and Simple passphrase salting,
+hashing and authentication.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =head1 SYNOPSIS
 
@@ -86,9 +80,8 @@ This module is a subclass of
 L<Authen::Passphrase::SaltedDigest|http://search.cpan.org/perldoc?Authen::Passphrase::SaltedDigest>.
 It adds two features to make your life a little easier and safer.  First, it
 simplifies the user interface by selecting reasonable (and secure) defaults.
-Second, in generating salt, it uses the high quality, secure random number
-generator provided by
-L<Math::Random::Secure|http://search.cpan.org/perldoc?Math::Random::Secure>.
+Second, in generating salt, it uses the high quality, CSPRNG provided by
+L<Bytes::Random::Secure|http://search.cpan.org/perldoc?Bytes::Random::Secure>.
 
 Some examples:
 
@@ -133,8 +126,8 @@ It is also designed to easily authenticate a user supplied passphrase against
 a given salt and hash.
 
 The presumed use-case is for user authentication where a salt and a password
-hash will be stored in a user database.  The simple interface should fit
-into a broad range of authentication systems with minimal clutter.
+hash will be stored in a database of user logins.  The simple interface should
+fit into a broad range of authentication systems with minimal clutter.
 
 Authen::Passphrase::SaltedSHA512 is a subclass of
 L<Authen::Passphrase::SaltedDigest|http://search.cpan.org/perldoc?Authen::Passphrase::SaltedDigest>
@@ -143,20 +136,18 @@ don't have to spend a week reading articles on which algorithm to use, and how
 to generate a good salt.
 
 The hashing algorithm chosen is the SHA-512 hash function from the SHA-2
-family.  Currently SHA-512 is a leading edge standard in strong cryptography.
+family.  Currently SHA-512 is a leading edge standard in strong hashing.
 
 The salt generated when creating authentication credentials is a 512 bit
 random string.  The random number generating algorithm used comes from
-L<Math::Random::Secure|http://search.cpan.org/perldoc?Math::Random::Secure>.
-That module currently uses Math::Random::ISAAC, "I<...a
-cryptographically-strong random number generator with no known serious
-weaknesses.>"  Math::Random::Secure generates its seed using
-Crypt::Random::Source.  The reason that Math::Random::Secure was chosen over
-other random number generators is because of this design philosophy,
-documented in its POD: "I<If there are significant weaknesses found in ISAAC,
-we will change our backend to a more-secure random number generator. The goal
-is for Math::Random::Secure to be cryptographically strong, not to represent
-some specific random number generator.>"
+L<Bytes::Random::Secure|http://search.cpan.org/perldoc?Bytes::Random::Secure>.
+That module uses Math::Random::ISAAC, "I<...a cryptographically-strong random
+number generator with no known serious weaknesses.>"  Bytes::Random::Secure
+obtains its seed using Crypt::Random::Seed.  The reason that
+Bytes::Random::Secure was chosen over other random number generators is because
+that module has a light-weight dependency chain, a cryptographically strong
+random number generator, strong seeding (the hardest part of the CSPRNG problem)
+across a wide variety of platforms, and useful hex output.
 
 By using a 512 bit random salt, a maximum degree of entropy is achieved in the
 hashes generated by the SHA-512 algorithm.  Every time the constructor is
@@ -402,17 +393,15 @@ could still be appropriate.
 
 =head1 DEPENDENCIES
 
-Strong security doesn't come cheap.  This module has the following non-core
-dependencies:
+This module has the following non-core immediate dependencies:
 
+=over 4
 
-Authen::Passphrase (which provides Authen::Passphrase::SaltedDigest)
+=item Authen::Passphrase (which provides Authen::Passphrase::SaltedDigest)
 
+=item L<Bytes::Random::Secure|http://search.cpan.org/perldoc?Bytes::Random::Secure>
 
-L<Bytes::Random::Secure|http://search.cpan.org/perldoc?Bytes::Random::Secure>,
-which uses...
-L<Math::Random::Secure|http://search.cpan.org/perldoc?Math::Random::Secure>
-
+=back
 
 Each of these has its own list of non-core dependencies as well.  But it's a
 well-tested set of dependencies, with broad portability demonstrated by the
@@ -446,7 +435,7 @@ the module's build directory.
 
 =item * L<Authen::Passphrase::SaltedDigest|http://search.cpan.org/perldoc?Authen::Passphrase::SaltedDigest>
 
-=item * L<Math::Random::Secure|http://search.cpan.org/perldoc?Math::Random::Secure>
+=item * L<Bytes::Random::Secure|http://search.cpan.org/perldoc?Bytes::Random::Secure>
 
 =item * L<Wikipedia article on SHA-2 (SHA-512)|http://en.wikipedia.org/wiki/SHA-2>
 
